==> V3.1.zip: V3.1/zhangjianhua0716.sql <==
ALTER TABLE `risk_news`
ADD COLUMN `uuid`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'UUID' AFTER `othercategorynews`;

DROP TABLE IF EXISTS `sys_tips`;
CREATE TABLE `sys_tips` (
  `oid` int(11) NOT NULL AUTO_INCREMENT,
  `createOn` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `updateOn` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `status` varchar(255) DEFAULT NULL COMMENT '状态（0：已取消，1：已开启，2进行中）',
  `website` varchar(255) DEFAULT NULL COMMENT '站点（1：风评系统，2：申报系统-陕西，3：申报系统-广西）',
  `startTime` datetime DEFAULT NULL COMMENT '开始时间',
  `endTime` datetime DEFAULT NULL COMMENT '结束时间',
  `title` varchar(255) DEFAULT NULL COMMENT '标题',
  `content` varchar(255) DEFAULT NULL COMMENT '内容',
  `provinceCode` varchar(255) DEFAULT NULL COMMENT '省份代码',
  PRIMARY KEY (`oid`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COMMENT='系统提示';

/*字典表插入新类型*/
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('548', NULL, NULL, '专业类型', '安全管理-安全生产管理', '1', 'PROFESSIONTYPE', '1');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('549', NULL, NULL, '专业类型', '安全管理-保安管理', '2', 'PROFESSIONTYPE', '2');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('550', NULL, NULL, '专业类型', '安全管理-公共安全管理', '3', 'PROFESSIONTYPE', '3');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('551', NULL, NULL, '专业类型', '安全管理-安全评价', '4', 'PROFESSIONTYPE', '4');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('552', NULL, NULL, '专业类型', '建筑施工-建筑设计', '5', 'PROFESSIONTYPE', '5');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('553', NULL, NULL, '专业类型', '建筑施工-建筑施工', '6', 'PROFESSIONTYPE', '6');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('554', NULL, NULL, '专业类型', '建筑施工-工程监理', '7', 'PROFESSIONTYPE', '7');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('555', NULL, NULL, '专业类型', '安装工程-建筑安装', '8', 'PROFESSIONTYPE', '8');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('556', NULL, NULL, '专业类型', '安装工程-水电安装', '9', 'PROFESSIONTYPE', '9');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('557', NULL, NULL, '专业类型', '安装工程-消防工程', '10', 'PROFESSIONTYPE', '10');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('558', NULL, NULL, '专业类型', '结构设计', '11', 'PROFESSIONTYPE', '11');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('559', NULL, NULL, '专业类型', '市政工程', '12', 'PROFESSIONTYPE', '12');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('560', NULL, NULL, '专业类型', '园林景观', '13', 'PROFESSIONTYPE', '13');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('561', NULL, NULL, '专业类型', '路桥', '14', 'PROFESSIONTYPE', '14');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('562', NULL, NULL, '专业类型', '测量', '15', 'PROFESSIONTYPE', '15');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('563', NULL, NULL, '专业类型', '地质勘查', '16', 'PROFESSIONTYPE', '16');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('564', NULL, NULL, '专业类型', '机械工程', '17', 'PROFESSIONTYPE', '17');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('565', NULL, NULL, '专业类型', '机电', '18', 'PROFESSIONTYPE', '18');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('566', NULL, NULL, '专业类型', '电子', '19', 'PROFESSIONTYPE', '19');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('567', NULL, NULL, '专业类型', '化工', '20', 'PROFESSIONTYPE', '20');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('568', NULL, NULL, '专业类型', '环境工程', '21', 'PROFESSIONTYPE', '21');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('569', NULL, NULL, '专业类型', '冷暖通风', '22', 'PROFESSIONTYPE', '22');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('570', NULL, NULL, '专业类型', '电气', '23', 'PROFESSIONTYPE', '23');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('571', NULL, NULL, '专业类型', '自动化', '24', 'PROFESSIONTYPE', '24');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('572', NULL, NULL, '专业类型', '船舶', '25', 'PROFESSIONTYPE', '25');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('573', NULL, NULL, '专业类型', '通信', '26', 'PROFESSIONTYPE', '26');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('574', NULL, NULL, '专业类型', '材料', '27', 'PROFESSIONTYPE', '27');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('575', NULL, NULL, '专业类型', '水利水电', '28', 'PROFESSIONTYPE', '28');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('576', NULL, NULL, '专业类型', '冶金工程', '29', 'PROFESSIONTYPE', '29');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('577', NULL, NULL, '专业类型', '电力', '30', 'PROFESSIONTYPE', '30');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('578', NULL, NULL, '专业类型', '港口与航道', '31', 'PROFESSIONTYPE', '31');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('579', NULL, NULL, '专业类型', '燃气', '32', 'PROFESSIONTYPE', '32');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('580', NULL, NULL, '行业类型', '农林牧渔业', '1', 'INDUSTRYTYPE', '1');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('581', NULL, NULL, '行业类型', '采矿业', '2', 'INDUSTRYTYPE', '2');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('582', NULL, NULL, '行业类型', '制造业', '3', 'INDUSTRYTYPE', '3');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('583', NULL, NULL, '行业类型', '电力、热力、燃气及水生产和供应业', '4', 'INDUSTRYTYPE', '4');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('584', NULL, NULL, '行业类型', '建筑业', '5', 'INDUSTRYTYPE', '5');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('585', NULL, NULL, '行业类型', '批发和零售业', '6', 'INDUSTRYTYPE', '6');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('586', NULL, NULL, '行业类型', '交通运输、仓储和邮政业', '7', 'INDUSTRYTYPE', '7');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('587', NULL, NULL, '行业类型', '住宿和餐饮业', '8', 'INDUSTRYTYPE', '8');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('588', NULL, NULL, '行业类型', '信息传输、软件和信息技术服务业', '9', 'INDUSTRYTYPE', '9');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('589', NULL, NULL, '行业类型', '金融业', '10', 'INDUSTRYTYPE', '10');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('590', NULL, NULL, '行业类型', '房地产业', '11', 'INDUSTRYTYPE', '11');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('591', NULL, NULL, '行业类型', '租赁和商务服务业', '12', 'INDUSTRYTYPE', '12');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('592', NULL, NULL, '行业类型', '科学研究和技术服务业', '13', 'INDUSTRYTYPE', '13');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('593', NULL, NULL, '行业类型', '水利、环境和公共设施管理业', '14', 'INDUSTRYTYPE', '14');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('594', NULL, NULL, '行业类型', '居民服务、修理和其他业务', '15', 'INDUSTRYTYPE', '15');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('595', NULL, NULL, '行业类型', '教育', '16', 'INDUSTRYTYPE', '16');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('596', NULL, NULL, '行业类型', '卫生和社会工作', '17', 'INDUSTRYTYPE', '17');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('597', NULL, NULL, '行业类型', '文化、体育和娱乐业', '18', 'INDUSTRYTYPE', '18');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('598', NULL, NULL, '行业类型', '公共管理、社会保障和社会组织', '19', 'INDUSTRYTYPE', '19');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('599', NULL, NULL, '行业类型', '国际组织', '20', 'INDUSTRYTYPE', '20');

==> V3.1.1.zip: V3.1.1/zhangjianhua0716.sql <==

/*张建华全部3.1.1脚本*/

/*专家类型配置表 by 张建华 2018年7月13日09:55:38*/
CREATE TABLE `risk_expert_type` (
  `oid` int(11) NOT NULL AUTO_INCREMENT,
  `createOn` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `updateOn` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `expertType` varchar(255) DEFAULT NULL COMMENT '专家类型描述',
  `expertName` varchar(255) DEFAULT NULL COMMENT '专家类型名称',
  PRIMARY KEY (`oid`)
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8 COMMENT='专家类型配置表';


/*专家类型配置基础信息 by 张建华 2018年7月13日09:55:41*/
INSERT INTO `risk_expert_type` VALUES ('1', '2018-07-12 16:13:38', '2018-07-12 16:13:40', '16', '撰写专家');
INSERT INTO `risk_expert_type` VALUES ('2', '2018-07-12 16:13:41', '2018-07-12 16:13:43', '14', '勘查人员');
INSERT INTO `risk_expert_type` VALUES ('3', '2018-07-12 16:13:43', '2018-07-12 16:13:46', '17', '勘查专家');

ALTER TABLE `risk_news`
ADD COLUMN `uuid`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT 'UUID' AFTER `othercategorynews`;


CREATE TABLE `sys_tips` (
  `oid` int(11) NOT NULL AUTO_INCREMENT,
  `createOn` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `updateOn` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `status` varchar(255) DEFAULT NULL COMMENT '状态（0：已取消，1：已开启，2进行中）',
  `website` varchar(255) DEFAULT NULL COMMENT '站点（1：风评系统，2：申报系统-陕西，3：申报系统-广西）',
  `startTime` datetime DEFAULT NULL COMMENT '开始时间',
  `endTime` datetime DEFAULT NULL COMMENT '结束时间',
  `title` varchar(255) DEFAULT NULL COMMENT '标题',
  `content` varchar(255) DEFAULT NULL COMMENT '内容',
  `provinceCode` varchar(255) DEFAULT NULL COMMENT '省份代码',
  PRIMARY KEY (`oid`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8 COMMENT='系统提示';


/*字典表插入新类型 2018年7月19日09:12:51*/
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('548', NULL, NULL, '专业类型', '安全管理-安全生产管理', '1', 'PROFESSIONTYPE', '1');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('549', NULL, NULL, '专业类型', '安全管理-保安管理', '2', 'PROFESSIONTYPE', '2');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('550', NULL, NULL, '专业类型', '安全管理-公共安全管理', '3', 'PROFESSIONTYPE', '3');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('551', NULL, NULL, '专业类型', '安全管理-安全评价', '4', 'PROFESSIONTYPE', '4');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('552', NULL, NULL, '专业类型', '建筑施工-建筑设计', '5', 'PROFESSIONTYPE', '5');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('553', NULL, NULL, '专业类型', '建筑施工-建筑施工', '6', 'PROFESSIONTYPE', '6');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('554', NULL, NULL, '专业类型', '建筑施工-工程监理', '7', 'PROFESSIONTYPE', '7');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('555', NULL, NULL, '专业类型', '安装工程-建筑安装', '8', 'PROFESSIONTYPE', '8');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('556', NULL, NULL, '专业类型', '安装工程-水电安装', '9', 'PROFESSIONTYPE', '9');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('557', NULL, NULL, '专业类型', '安装工程-消防工程', '10', 'PROFESSIONTYPE', '10');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('558', NULL, NULL, '专业类型', '结构设计', '11', 'PROFESSIONTYPE', '11');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('559', NULL, NULL, '专业类型', '市政工程', '12', 'PROFESSIONTYPE', '12');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('560', NULL, NULL, '专业类型', '园林景观', '13', 'PROFESSIONTYPE', '13');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('561', NULL, NULL, '专业类型', '路桥', '14', 'PROFESSIONTYPE', '14');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('562', NULL, NULL, '专业类型', '测量', '15', 'PROFESSIONTYPE', '15');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('563', NULL, NULL, '专业类型', '地质勘查', '16', 'PROFESSIONTYPE', '16');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('564', NULL, NULL, '专业类型', '机械工程', '17', 'PROFESSIONTYPE', '17');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('565', NULL, NULL, '专业类型', '机电', '18', 'PROFESSIONTYPE', '18');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('566', NULL, NULL, '专业类型', '电子', '19', 'PROFESSIONTYPE', '19');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('567', NULL, NULL, '专业类型', '化工', '20', 'PROFESSIONTYPE', '20');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('568', NULL, NULL, '专业类型', '环境工程', '21', 'PROFESSIONTYPE', '21');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('569', NULL, NULL, '专业类型', '冷暖通风', '22', 'PROFESSIONTYPE', '22');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('570', NULL, NULL, '专业类型', '电气', '23', 'PROFESSIONTYPE', '23');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('571', NULL, NULL, '专业类型', '自动化', '24', 'PROFESSIONTYPE', '24');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('572', NULL, NULL, '专业类型', '船舶', '25', 'PROFESSIONTYPE', '25');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('573', NULL, NULL, '专业类型', '通信', '26', 'PROFESSIONTYPE', '26');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('574', NULL, NULL, '专业类型', '材料', '27', 'PROFESSIONTYPE', '27');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('575', NULL, NULL, '专业类型', '水利水电', '28', 'PROFESSIONTYPE', '28');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('576', NULL, NULL, '专业类型', '冶金工程', '29', 'PROFESSIONTYPE', '29');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('577', NULL, NULL, '专业类型', '电力', '30', 'PROFESSIONTYPE', '30');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('578', NULL, NULL, '专业类型', '港口与航道', '31', 'PROFESSIONTYPE', '31');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('579', NULL, NULL, '专业类型', '燃气', '32', 'PROFESSIONTYPE', '32');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('580', NULL, NULL, '行业类型', '农林牧渔业', '1', 'INDUSTRYTYPE', '1');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('581', NULL, NULL, '行业类型', '采矿业', '2', 'INDUSTRYTYPE', '2');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('582', NULL, NULL, '行业类型', '制造业', '3', 'INDUSTRYTYPE', '3');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('583', NULL, NULL, '行业类型', '电力、热力、燃气及水生产和供应业', '4', 'INDUSTRYTYPE', '4');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('584', NULL, NULL, '行业类型', '建筑业', '5', 'INDUSTRYTYPE', '5');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('585', NULL, NULL, '行业类型', '批发和零售业', '6', 'INDUSTRYTYPE', '6');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('586', NULL, NULL, '行业类型', '交通运输、仓储和邮政业', '7', 'INDUSTRYTYPE', '7');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('587', NULL, NULL, '行业类型', '住宿和餐饮业', '8', 'INDUSTRYTYPE', '8');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('588', NULL, NULL, '行业类型', '信息传输、软件和信息技术服务业', '9', 'INDUSTRYTYPE', '9');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('589', NULL, NULL, '行业类型', '金融业', '10', 'INDUSTRYTYPE', '10');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('590', NULL, NULL, '行业类型', '房地产业', '11', 'INDUSTRYTYPE', '11');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('591', NULL, NULL, '行业类型', '租赁和商务服务业', '12', 'INDUSTRYTYPE', '12');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('592', NULL, NULL, '行业类型', '科学研究和技术服务业', '13', 'INDUSTRYTYPE', '13');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('593', NULL, NULL, '行业类型', '水利、环境和公共设施管理业', '14', 'INDUSTRYTYPE', '14');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('594', NULL, NULL, '行业类型', '居民服务、修理和其他业务', '15', 'INDUSTRYTYPE', '15');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('595', NULL, NULL, '行业类型', '教育', '16', 'INDUSTRYTYPE', '16');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('596', NULL, NULL, '行业类型', '卫生和社会工作', '17', 'INDUSTRYTYPE', '17');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('597', NULL, NULL, '行业类型', '文化、体育和娱乐业', '18', 'INDUSTRYTYPE', '18');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('598', NULL, NULL, '行业类型', '公共管理、社会保障和社会组织', '19', 'INDUSTRYTYPE', '19');
INSERT INTO `sys_dict` (`oid`, `createOn`, `updateOn`, `description`, `label`, `sort`, `type`, `value`) VALUES ('599', NULL, NULL, '行业类型', '国际组织', '20', 'INDUSTRYTYPE', '20');


ALTER TABLE `risk_activityexpress`
MODIFY COLUMN `invoiceExpressMode`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '不寄送/普通发票/增值税发票 ' AFTER `expressNumber`,
MODIFY COLUMN `reportExpressMode`  varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL COMMENT '不寄送报告/寄送报告 ' AFTER `registerAddressInvoice`;

UPDATE `risk_menu` SET `oid`='10104', `createOn`='2017-05-18 22:39:34', `updateOn`=NULL, `menuCode`='', `menuDesc`='4', `menuName`='活动管理', `parent_id`='101', `menuType`='1' WHERE (`oid`='10104');

INSERT INTO `risk_menu` (`oid`, `createOn`, `updateOn`, `menuCode`, `menuDesc`, `menuName`, `parent_id`, `menuType`) VALUES ('1010402', '2017-05-18 22:39:34', NULL, '', '2', '许可列表', '10104', '2');
INSERT INTO `risk_menu` (`oid`, `createOn`, `updateOn`, `menuCode`, `menuDesc`, `menuName`, `parent_id`, `menuType`) VALUES ('1010403', '2017-05-18 22:39:34', NULL, '', '3', '备案列表', '10104', '2');

INSERT INTO `risk_systemconfig` (`oid`, `createOn`, `updateOn`, `syskey`, `sysvalue`, `description`) VALUES ('34', '2018-07-09 16:05:36', '2018-07-09 16:05:38', 'envi_code', '1', '系统环境');
